OC.L10N.register(
    "text",
    {
    "New text file" : "Uus tekstifail",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "Use current version" : "Kasuta praegust versiooni",
    "Use the saved version" : "Kasuta salvestatud versiooni",
    "Guest" : "Külaline",
    "guest" : "külaline",
    "Saved" : "Salvestatud",
    "Last saved {lastSaved}" : "Viimati salvestatud {lastSaved}",
    "Unsaved changes" : "Salvestamata muutused",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Unsupported image type" : "Pildi tüüp pole toetatud",
    "Info" : "Info",
    "Warning" : "Hoiatus",
    "Edit" : "Redigeeri"
},
"nplurals=2; plural=(n != 1);");
